# PostPublicNotificationDefinitionRequestCalloutHttpMethod

The HTTP method of the callout.

## Enum

* `GET` (value: `'GET'`)

* `PUT` (value: `'PUT'`)

* `POST` (value: `'POST'`)

* `DELETE` (value: `'DELETE'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


